'use strict';
import { simpleGit } from 'simple-git';
import { retrieveCommitMessages } from './retrieveCommitMessages.js';
import { validateClassPaths } from './validateClassPaths.js';
export async function extractTestClasses(fromRef, toRef, regex, sfdxConfigFile) {
    const options = {
        baseDir: process.cwd(),
        binary: 'git',
        maxConcurrentProcesses: 6,
        trimmed: true,
    };
    const git = simpleGit(options);
    const testClasses = new Set();
    const matchedMessages = await retrieveCommitMessages(fromRef, toRef, regex, git);
    matchedMessages.forEach((message) => {
        // Split the commit message by commas or spaces
        const classes = message.split(/,|\s/);
        classes.forEach((testClass) => {
            // Remove leading/trailing whitespaces and add non-empty strings to the set
            const trimmedClass = testClass.trim();
            if (trimmedClass !== '') {
                testClasses.add(trimmedClass);
            }
        });
    });
    const unvalidatedClasses = Array.from(testClasses);
    let validatedClasses = '';
    const result = unvalidatedClasses.length > 0
        ? await validateClassPaths(unvalidatedClasses, sfdxConfigFile, toRef, git)
        : { validatedClasses: new Set(), warnings: [] };
    let sortedClasses = [];
    if (result.validatedClasses.size > 0) {
        sortedClasses = Array.from(result.validatedClasses);
        sortedClasses = sortedClasses.sort((a, b) => a.localeCompare(b));
        validatedClasses = sortedClasses.join(' ');
    }
    return { validatedClasses, warnings: result.warnings };
}
//# sourceMappingURL=extractTestClasses.js.map